==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/APIServerNamedServingCertFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class APIServerNamedServingCertFluentImpl<A extends io.fabric8.openshift.api.model.APIServerNamedServingCertFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.APIServerNamedServingCertFluent<A>{
  public APIServerNamedServingCertFluentImpl() {
  }
  public APIServerNamedServingCertFluentImpl(io.fabric8.openshift.api.model.APIServerNamedServingCert instance) {
    this.withNames(instance.getNames()); 
    this.withServingCertificate(instance.getServingCertificate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> names = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder servingCertificate;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToNames(java.lang.Integer index,java.lang.String item) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    this.names.add(index, item);
    return (A)this;
  }
  public A setToNames(java.lang.Integer index,java.lang.String item) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    this.names.set(index, item); return (A)this;
  }
  public A addToNames(java.lang.String... items) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.names.add(item);} return (A)this;
  }
  public A addAllToNames(java.util.Collection<java.lang.String> items) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.names.add(item);} return (A)this;
  }
  public A removeFromNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public A removeAllFromNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getNames() {
    return this.names;
  }
  public java.lang.String getName(java.lang.Integer index) {
    return this.names.get(index);
  }
  public java.lang.String getFirstName() {
    return this.names.get(0);
  }
  public java.lang.String getLastName() {
    return this.names.get(names.size() - 1);
  }
  public java.lang.String getMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: names) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: names) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNames(java.util.List<java.lang.String> names) {
    if (names != null) {this.names = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : names){this.addToNames(item);}} else { this.names = null;} return (A) this;
  }
  public A withNames(java.lang.String... names) {
    if (this.names != null) {this.names.clear();}
    if (names != null) {for (java.lang.String item :names){ this.addToNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasNames() {
    return names != null && !names.isEmpty();
  }
  public A addNewName(java.lang.String arg0) {
    return (A)addToNames(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertificate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getServingCertificate() {
    return this.servingCertificate!=null?this.servingCertificate.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildServingCertificate() {
    return this.servingCertificate!=null?this.servingCertificate.build():null;
  }
  public A withServingCertificate(io.fabric8.openshift.api.model.SecretNameReference servingCertificate) {
    _visitables.get("servingCertificate").remove(this.servingCertificate);
    if (servingCertificate!=null){ this.servingCertificate= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(servingCertificate); _visitables.get("servingCertificate").add(this.servingCertificate);} return (A) this;
  }
  public java.lang.Boolean hasServingCertificate() {
    return this.servingCertificate != null;
  }
  public A withNewServingCertificate(java.lang.String name) {
    return (A)withServingCertificate(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> withNewServingCertificate() {
    return new io.fabric8.openshift.api.model.APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl();
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> withNewServingCertificateLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> editServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate());
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> editOrNewServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> editOrNewServingCertificateLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIServerNamedServingCertFluentImpl that = (APIServerNamedServingCertFluentImpl) o;
    if (names != null ? !names.equals(that.names) :that.names != null) return false;
    if (servingCertificate != null ? !servingCertificate.equals(that.servingCertificate) :that.servingCertificate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(names,  servingCertificate,  additionalProperties,  super.hashCode());
  }
  public class ServingCertificateNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<N>> implements io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServingCertificateNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ServingCertificateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) APIServerNamedServingCertFluentImpl.this.withServingCertificate(builder.build());
    }
    public N endServingCertificate() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/APIServerNamedServingCertFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class APIServerNamedServingCertFluentImpl<A extends io.fabric8.openshift.api.model.APIServerNamedServingCertFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.APIServerNamedServingCertFluent<A>{
  public APIServerNamedServingCertFluentImpl() {
  }
  public APIServerNamedServingCertFluentImpl(io.fabric8.openshift.api.model.APIServerNamedServingCert instance) {
    this.withNames(instance.getNames()); 
    this.withServingCertificate(instance.getServingCertificate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> names = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder servingCertificate;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToNames(java.lang.Integer index,java.lang.String item) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    this.names.add(index, item);
    return (A)this;
  }
  public A setToNames(java.lang.Integer index,java.lang.String item) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    this.names.set(index, item); return (A)this;
  }
  public A addToNames(java.lang.String... items) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.names.add(item);} return (A)this;
  }
  public A addAllToNames(java.util.Collection<java.lang.String> items) {
    if (this.names == null) {this.names = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.names.add(item);} return (A)this;
  }
  public A removeFromNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public A removeAllFromNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.names!= null){ this.names.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getNames() {
    return this.names;
  }
  public java.lang.String getName(java.lang.Integer index) {
    return this.names.get(index);
  }
  public java.lang.String getFirstName() {
    return this.names.get(0);
  }
  public java.lang.String getLastName() {
    return this.names.get(names.size() - 1);
  }
  public java.lang.String getMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: names) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: names) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNames(java.util.List<java.lang.String> names) {
    if (names != null) {this.names = new java.util.ArrayList(); for (java.lang.String item : names){this.addToNames(item);}} else { this.names = null;} return (A) this;
  }
  public A withNames(java.lang.String... names) {
    if (this.names != null) {this.names.clear();}
    if (names != null) {for (java.lang.String item :names){ this.addToNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasNames() {
    return names != null && !names.isEmpty();
  }
  public A addNewName(java.lang.String arg0) {
    return (A)addToNames(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertificate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getServingCertificate() {
    return this.servingCertificate!=null?this.servingCertificate.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildServingCertificate() {
    return this.servingCertificate!=null?this.servingCertificate.build():null;
  }
  public A withServingCertificate(io.fabric8.openshift.api.model.SecretNameReference servingCertificate) {
    _visitables.get("servingCertificate").remove(this.servingCertificate);
    if (servingCertificate!=null){ this.servingCertificate= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(servingCertificate); _visitables.get("servingCertificate").add(this.servingCertificate);} return (A) this;
  }
  public java.lang.Boolean hasServingCertificate() {
    return this.servingCertificate != null;
  }
  public A withNewServingCertificate(java.lang.String name) {
    return (A)withServingCertificate(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> withNewServingCertificate() {
    return new io.fabric8.openshift.api.model.APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl();
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> withNewServingCertificateLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.APIServerNamedServingCertFluentImpl.ServingCertificateNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> editServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate());
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> editOrNewServingCertificate() {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<A> editOrNewServingCertificateLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewServingCertificateLike(getServingCertificate() != null ? getServingCertificate(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIServerNamedServingCertFluentImpl that = (APIServerNamedServingCertFluentImpl) o;
    if (names != null ? !names.equals(that.names) :that.names != null) return false;
    if (servingCertificate != null ? !servingCertificate.equals(that.servingCertificate) :that.servingCertificate != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(names,  servingCertificate,  additionalProperties,  super.hashCode());
  }
  public class ServingCertificateNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<N>> implements io.fabric8.openshift.api.model.APIServerNamedServingCertFluent.ServingCertificateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServingCertificateNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ServingCertificateNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) APIServerNamedServingCertFluentImpl.this.withServingCertificate(builder.build());
    }
    public N endServingCertificate() {
      return and();
    }
    
  }
  
}
